@@ -41,6 +41,7 @@ from neuro_cli.formatters.utils import (
     get_datetime_formatter,
     uri_formatter,
 )
+from neuro_cli.parse_utils import parse_timedelta
 
 from .const import EX_OSFILE
 from .formatters.blob_storage import (
@@ -146,6 +147,169 @@ async def mkbucket(
         root.print(bucket_fmtr(bucket))
 
 
+@command()
+@option(
+    "--cluster",
+    type=CLUSTER,
+    help="Perform in a specified cluster (the current cluster by default).",
+)
+@option(
+    "--name",
+    type=BUCKET_NAME,
+    metavar="NAME",
+    help="Optional bucket name",
+    default=None,
+)
+@option(
+    "--provider",
+    type=click.Choice(["aws", "gcp", "azure"], case_sensitive=False),
+    metavar="PROVIDER",
+    help="Bucket provider that hosts bucket",
+    required=True,
+)
+@option(
+    "--provider-bucket-name",
+    type=str,
+    metavar="EXTERNAL_NAME",
+    help="Name of bucket (or container in case of Azure) inside the provider",
+    required=True,
+)
+@option(
+    "--aws-access-key-id",
+    type=str,
+    metavar="AWS_ACCESS_KEY_ID",
+    help="AWS access_key_id to use to access the bucket. "
+    " Required when PROVIDER is 'aws'",
+    default=False,
+)
+@option(
+    "--aws-secret-access-key",
+    type=str,
+    metavar="AWS_SECRET_ACCESS_KEY",
+    help="AWS secret_access_key to use to access the bucket. "
+    "Required when PROVIDER is 'aws'",
+    default=False,
+)
+@option(
+    "--aws-region-name",
+    type=str,
+    metavar="AWS_REGION",
+    help="AWS region to use to access the bucket.",
+    default="us-east-1",
+)
+@option(
+    "--aws-endpoint-url",
+    type=str,
+    metavar="AWS_ENDPOINT",
+    help="AWS endpoint to use to access the bucket. "
+    "Usually you need to set this if "
+    "you use non-AWS S3 compatible provider",
+    default=None,
+)
+@option(
+    "--azure-storage-account-url",
+    type=str,
+    metavar="AZURE_STORAGE_ACCOUNT_URL",
+    help="Azure account url. Usually it has following format: "
+    "https://<account_id>.blob.core.windows.net "
+    "Required when PROVIDER is 'azure'",
+    default=False,
+)
+@option(
+    "--azure-storage-sas-token",
+    type=str,
+    metavar="AZURE_SAS",
+    help="Azure shared access signature token that grants access to imported bucket. "
+    "Either this or AZURE_STORAGE_CREDENTIAL is required when PROVIDER is 'azure'",
+    default=False,
+)
+@option(
+    "--azure-storage-credential",
+    type=str,
+    metavar="AZURE_STORAGE_CREDENTIAL",
+    help="Azure storage credential that grants access to imported bucket. "
+    "Either this or AZURE_SAS is required when PROVIDER is 'azure'",
+    default=False,
+)
+@option(
+    "--gcp-sa-credential",
+    type=str,
+    metavar="GCP_SA_CREDNETIAL",
+    help="GCP service account credential in form of base64 encoded json "
+    "string that grants access to imported bucket. "
+    "Required when PROVIDER is 'gcp'",
+    default=False,
+)
+async def importbucket(
+    root: Root,
+    provider: str,
+    provider_bucket_name: str,
+    aws_access_key_id: Optional[str] = None,
+    aws_secret_access_key: Optional[str] = None,
+    aws_region_name: str = "us-east-1",
+    aws_endpoint_url: Optional[str] = None,
+    azure_storage_account_url: Optional[str] = None,
+    azure_storage_sas_token: Optional[str] = None,
+    azure_storage_credential: Optional[str] = None,
+    gcp_sa_credential: Optional[str] = None,
+    name: Optional[str] = None,
+    cluster: Optional[str] = None,
+) -> None:
+    """
+    Import an existing bucket.
+    """
+    provider_type = Bucket.Provider(provider)
+    credentials = {}
+    if provider_type == Bucket.Provider.AWS:
+        if aws_access_key_id is None:
+            raise ValueError("--aws-access-key-id is required when PROVIDER is 'aws'")
+        if aws_secret_access_key is None:
+            raise ValueError(
+                "--aws-secret-access-key is required when PROVIDER is 'aws'"
+            )
+        credentials["access_key_id"] = aws_access_key_id
+        credentials["secret_access_key"] = aws_secret_access_key
+        credentials["region_name"] = aws_region_name
+        if aws_endpoint_url:
+            credentials["endpoint_url"] = aws_endpoint_url
+    elif provider_type == Bucket.Provider.AZURE:
+        if azure_storage_account_url is None:
+            raise ValueError(
+                "--azure-storage-account-url is required when PROVIDER is 'azure'"
+            )
+        credentials["storage_endpoint"] = azure_storage_account_url
+        if azure_storage_credential is not None:
+            credentials["credential"] = azure_storage_credential
+        elif azure_storage_sas_token is not None:
+            credentials["sas_token"] = azure_storage_sas_token
+        else:
+            raise ValueError(
+                "Either --azure-storage-credential or --azure-storage-sas-token "
+                "should be specified when PROVIDER is 'azure'"
+            )
+    elif provider_type == Bucket.Provider.GCP:
+        if gcp_sa_credential is None:
+            raise ValueError("--gcp-sa-credential is required when PROVIDER is 'gcp'")
+        credentials["key_data"] = gcp_sa_credential
+    else:
+        raise ValueError(
+            f"Importing of buckets with provider {provider} is not supported"
+        )
+
+    bucket = await root.client.buckets.import_external(
+        provider=provider_type,
+        provider_bucket_name=provider_bucket_name,
+        credentials=credentials,
+        name=name,
+        cluster_name=cluster,
+    )
+    bucket_fmtr = BucketFormatter(
+        str, datetime_formatter=get_datetime_formatter(root.iso_datetime_format)
+    )
+    with root.pager():
+        root.print(bucket_fmtr(bucket))
+
+
 @command()
 @option(
     "--cluster",
@@ -158,7 +322,7 @@ async def statbucket(
     root: Root, cluster: Optional[str], bucket: str, full_uri: bool
 ) -> None:
     """
-    Get bucket BUCKET_ID.
+    Get bucket BUCKET.
     """
     bucket_id = await resolve_bucket(bucket, client=root.client, cluster_name=cluster)
     bucket_obj = await root.client.buckets.get(bucket_id, cluster_name=cluster)
@@ -185,7 +349,7 @@ async def statbucket(
 @argument("buckets", type=BUCKET, nargs=-1, required=True)
 async def rmbucket(root: Root, cluster: Optional[str], buckets: Sequence[str]) -> None:
     """
-    Remove bucket DISK_ID.
+    Remove bucket BUCKET.
     """
     for bucket in buckets:
         bucket_id = await resolve_bucket(
@@ -196,6 +360,37 @@ async def rmbucket(root: Root, cluster: Optional[str], buckets: Sequence[str]) -
             root.print(f"Bucket with id '{bucket_id}' was successfully removed.")
 
 
+@command()
+@option(
+    "--cluster",
+    type=CLUSTER,
+    help="Perform on a specified cluster (the current cluster by default).",
+)
+@argument("bucket", type=BUCKET, required=True)
+@argument(
+    "public_level",
+    type=click.Choice(["public", "private"], case_sensitive=False),
+    required=True,
+)
+async def set_bucket_publicity(
+    root: Root, cluster: Optional[str], bucket: str, public_level: str
+) -> None:
+    """
+    Change public access settings for bucket BUCKET.
+
+    Examples:
+
+      neuro blob set-bucket-publicity my-bucket public
+      neuro blob set-bucket-publicity my-bucket private
+    """
+    public = public_level == "public"
+    await root.client.buckets.set_public_access(bucket, public, cluster_name=cluster)
+    if root.verbosity >= 0:
+        root.print(
+            f"Bucket '{bucket}' was made {'public' if public else 'non-public'}."
+        )
+
+
 # Object level commands
 
 
@@ -626,6 +821,36 @@ async def rm(
         sys.exit(EX_OSFILE)
 
 
+@command()
+@argument(
+    "path",
+    required=True,
+    type=PlatformURIType(allowed_schemes=["file", "blob"]),
+)
+@option(
+    "--expires",
+    type=str,
+    metavar="TIMEDELTA",
+    help="Duration this signature will be valid in the format '1h2m3s'",
+    show_default=True,
+    default="1h",
+)
+async def sign_url(
+    root: Root,
+    path: URL,
+    expires: str,
+) -> None:
+    """
+    Make signed url for blob in bucket.
+    """
+    expires_delta = parse_timedelta(expires)
+    signed_url = await root.client.buckets.make_signed_url(
+        path, int(expires_delta.total_seconds())
+    )
+
+    root.print(signed_url)
+
+
 # Bucket credentials commands
 
 
@@ -646,7 +871,7 @@ def make_bucket_getter(
 )
 async def lscredentials(root: Root, cluster: Optional[str]) -> None:
     """
-    List credentials.
+    List bucket credentials.
     """
     if root.quiet:
         fmtr: BaseBucketCredentialsFormatter = SimpleBucketCredentialsFormatter()
@@ -679,22 +904,28 @@ async def lscredentials(root: Root, cluster: Optional[str]) -> None:
     help="Optional bucket credential name",
     default=None,
 )
+@option(
+    "--read-only",
+    is_flag=True,
+    help="Make read-only credential",
+)
 @argument("buckets", type=BUCKET, nargs=-1, required=True)
 async def mkcredentials(
     root: Root,
     buckets: Sequence[str],
     name: Optional[str] = None,
     cluster: Optional[str] = None,
+    read_only: bool = False,
 ) -> None:
     """
-    Create a new bucket crednetial.
+    Create a new bucket credential.
     """
     bucket_ids = [
         await resolve_bucket(bucket, client=root.client, cluster_name=cluster)
         for bucket in buckets
     ]
     credential = await root.client.buckets.persistent_credentials_create(
-        name=name, cluster_name=cluster, bucket_ids=bucket_ids
+        name=name, cluster_name=cluster, read_only=read_only, bucket_ids=bucket_ids
     )
 
     fmtr = BucketCredentialFormatter(make_bucket_getter(root.client, cluster))
@@ -713,7 +944,7 @@ async def statcredentials(
     root: Root, cluster: Optional[str], bucket_credential: str
 ) -> None:
     """
-    Get bucket BUCKET_ID.
+    Get bucket credential BUCKET_CREDENTIAL.
     """
     credential_id = await resolve_bucket_credential(
         bucket_credential, client=root.client, cluster_name=cluster
@@ -738,7 +969,7 @@ async def rmcredentials(
     root: Root, cluster: Optional[str], credentials: Sequence[str]
 ) -> None:
     """
-    Remove bucket DISK_ID.
+    Remove bucket credential BUCKET_CREDENTIAL.
     """
     for credential in credentials:
         credential_id = await resolve_bucket_credential(
@@ -755,9 +986,10 @@ async def rmcredentials(
 
 blob_storage.add_command(lsbucket)
 blob_storage.add_command(mkbucket)
+blob_storage.add_command(importbucket)
 blob_storage.add_command(statbucket)
 blob_storage.add_command(rmbucket)
-
+blob_storage.add_command(set_bucket_publicity)
 
 blob_storage.add_command(lscredentials)
 blob_storage.add_command(mkcredentials)
@@ -768,3 +1000,4 @@ blob_storage.add_command(cp)
 blob_storage.add_command(ls)
 blob_storage.add_command(glob)
 blob_storage.add_command(rm)
+blob_storage.add_command(sign_url)
