@@ -7,6 +7,7 @@ from unittest import mock
 from neuro_sdk import Preset
 from neuro_sdk.admin import _Admin, _ClusterUser, _ClusterUserRoleType
 from neuro_sdk.config import Config
+from neuro_sdk.users import Quota
 
 from .conftest import SysCapWithCode
 
@@ -20,7 +21,7 @@ def test_add_cluster_user_print_result(run_cli: _RunCli) -> None:
             cluster_name: str, user_name: str, role: str
         ) -> _ClusterUser:
             # NOTE: We return a different role to check that we print it to user
-            return _ClusterUser(user_name, _ClusterUserRoleType.MANAGER)
+            return _ClusterUser(user_name, _ClusterUserRoleType.MANAGER, quota=Quota())
 
         mocked.side_effect = add_cluster_user
         capture = run_cli(["admin", "add-cluster-user", "default", "ivan", "admin"])
